==> org.apache.sling.event-4.3.12-source-release.zip: org.apache.sling.event-4.3.12/src/main/java/org/apache/sling/event/impl/support/BatchResourceRemover.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.event.impl.support;

import org.apache.sling.api.resource.PersistenceException;
import org.apache.sling.api.resource.Resource;
import org.apache.sling.api.resource.ResourceResolver;

/**
 * This class can be used for batch removal of resources
 */
public class BatchResourceRemover {

    private final int max;

    private int count;

    public BatchResourceRemover() {
        this(50);
    }

    public BatchResourceRemover(final int batchSize) {
        this.max = batchSize;
    }

    public void delete(final Resource rsrc )
    throws PersistenceException {
        final ResourceResolver resolver = rsrc.getResourceResolver();
        for(final Resource child : rsrc.getChildren()) {
            delete(child);
        }
        resolver.delete(rsrc);
        count++;
        if ( count >= max ) {
            resolver.commit();
            count = 0;
        }
    }
}

==> org.apache.sling.event-4.4.0-source-release.zip: org.apache.sling.event-4.4.0/src/main/java/org/apache/sling/event/impl/support/BatchResourceRemover.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.event.impl.support;

import org.apache.sling.api.resource.PersistenceException;
import org.apache.sling.api.resource.Resource;
import org.apache.sling.api.resource.ResourceResolver;

/**
 * This class can be used for batch removal of resources
 */
public class BatchResourceRemover {

    private final int max;

    private int count;

    public BatchResourceRemover() {
        this(50);
    }

    public BatchResourceRemover(final int batchSize) {
        this.max = batchSize;
    }

    public void delete(final Resource rsrc) throws PersistenceException {
        final ResourceResolver resolver = rsrc.getResourceResolver();
        for (final Resource child : rsrc.getChildren()) {
            delete(child);
        }
        resolver.delete(rsrc);
        count++;
        if (count >= max) {
            resolver.commit();
            count = 0;
        }
    }
}
